@@ -22,7 +22,7 @@ from oslo_config import cfg
 from sahara.conductor import resource as r
 from sahara.db import base as db_base
 from sahara.service.castellan import utils as key_manager
-from sahara.service import shares
+from sahara.service.edp.utils import shares
 from sahara.utils import configs
 from sahara.utils import crypto
 
@@ -33,6 +33,7 @@ CLUSTER_DEFAULTS = {
     "cluster_configs": {},
     "status": "undefined",
     "anti_affinity": [],
+    "anti_affinity_ratio": 1,
     "status_description": "",
     "info": {},
     "rollback_info": {},
@@ -103,7 +104,7 @@ class ConductorManager(db_base.Base):
     """This class aimed to conduct things.
 
     The methods in the base API for sahara-conductor are various proxy
-    operations that allows other services to get specific work done without
+    operations that allow other services to get specific work done without
     locally accessing the database.
 
     Additionally it performs some template-to-object copying magic.
@@ -199,6 +200,7 @@ class ConductorManager(db_base.Base):
             del c_tmpl['id']
             del c_tmpl['is_public']
             del c_tmpl['is_protected']
+            del c_tmpl['tenant_id']
 
             # updating with cluster_template values
             merged_values.update(c_tmpl)
@@ -607,6 +609,9 @@ class ConductorManager(db_base.Base):
         if values.get('extra') and values['extra'].get('password'):
             values['extra']['password'] = key_manager.store_secret(
                 values['extra']['password'], context)
+        if values.get('extra') and values['extra'].get('secretkey'):
+            values['extra']['secretkey'] = key_manager.store_secret(
+                values['extra']['secretkey'], context)
         return self.db.job_binary_create(context, values)
 
     def job_binary_destroy(self, context, job_binary):
@@ -615,11 +620,16 @@ class ConductorManager(db_base.Base):
         # in cases where the credentials to access the job binary are
         # stored with the record and the external key manager is being
         # used, we need to delete the key from the external manager.
-        if (CONF.use_barbican_key_manager and not
-                CONF.use_domain_for_proxy_users):
+        if CONF.use_barbican_key_manager:
             jb_record = self.job_binary_get(context, job_binary)
-            if jb_record.get('extra') and jb_record['extra'].get('password'):
-                key_manager.delete_secret(jb_record['extra']['password'],
+            if not CONF.use_domain_for_proxy_users:
+                if (jb_record.get('extra') and
+                        jb_record['extra'].get('password')):
+                    key_manager.delete_secret(jb_record['extra']['password'],
+                                              context)
+            if (jb_record.get('extra') and
+                    jb_record['extra'].get('secretkey')):
+                key_manager.delete_secret(jb_record['extra']['secretkey'],
                                           context)
         self.db.job_binary_destroy(context, job_binary)
 
@@ -635,18 +645,25 @@ class ConductorManager(db_base.Base):
         # the previous key and check to see if it has changed, but it
         # seems less expensive to just delete the old and create a new
         # one.
-        if (CONF.use_barbican_key_manager and not
-                CONF.use_domain_for_proxy_users):
+        if CONF.use_barbican_key_manager:
             # first we retrieve the original record to get the old key
             # uuid, and delete it.
-            jb_record = self.job_binary_get(context, id)
-            if jb_record.get('extra') and jb_record['extra'].get('password'):
-                key_manager.delete_secret(jb_record['extra']['password'],
-                                          context)
             # next we create the new key.
-            if values.get('extra') and values['extra'].get('password'):
-                values['extra']['password'] = key_manager.store_secret(
-                    values['extra']['password'], context)
+            jb_record = self.job_binary_get(context, id)
+            if not CONF.use_domain_for_proxy_users:
+                if (jb_record.get('extra') and
+                        jb_record['extra'].get('password')):
+                    key_manager.delete_secret(jb_record['extra']['password'],
+                                              context)
+                if values.get('extra') and values['extra'].get('password'):
+                    values['extra']['password'] = key_manager.store_secret(
+                        values['extra']['password'], context)
+            if jb_record.get('extra') and jb_record['extra'].get('secretkey'):
+                key_manager.delete_secret(jb_record['extra']['secretkey'],
+                                          context)
+            if values.get('extra') and values['extra'].get('secretkey'):
+                values['extra']['secretkey'] = key_manager.store_secret(
+                    values['extra']['secretkey'], context)
         return self.db.job_binary_update(context, values)
 
     # JobBinaryInternal ops
@@ -754,3 +771,23 @@ class ConductorManager(db_base.Base):
         """Return updated health check with the specified health_check_id."""
         return self.db.cluster_health_check_update(
             context, health_check_id, values)
+
+    def plugin_create(self, context, values):
+        """Return created DB entry for plugin."""
+        return self.db.plugin_create(context, values)
+
+    def plugin_get(self, context, name):
+        """Return DB entry for plugin."""
+        return self.db.plugin_get(context, name)
+
+    def plugin_get_all(self, context):
+        """Return DB entries for all plugins."""
+        return self.db.plugin_get_all(context)
+
+    def plugin_update(self, context, name, values):
+        """Return updated DB entry for plugin."""
+        return self.db.plugin_update(context, name, values)
+
+    def plugin_remove(self, context, name):
+        """Remove DB entry for plugin."""
+        return self.db.plugin_remove(context, name)
