@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import contextlib
 import os
 
 from oslo_config import cfg
@@ -25,13 +26,16 @@ import stevedore
 from sahara.api import acl
 from sahara.common import config as common_config
 from sahara import config
-from sahara.i18n import _LI
+from sahara import context
 from sahara.plugins import base as plugins_base
 from sahara.service import api
 from sahara.service.castellan import config as castellan
+from sahara.service.edp.data_sources import manager as ds_manager
+from sahara.service.edp.job_binaries import manager as jb_manager
 from sahara.service import ops as service_ops
 from sahara.service import periodic
 from sahara.utils.openstack import cinder
+from sahara.utils.openstack import keystone
 from sahara.utils import remote
 from sahara.utils import rpc as messaging
 
@@ -77,13 +81,22 @@ def setup_common(possible_topdir, service_name):
 
     # Validate other configurations (that may produce logs) here
     cinder.validate_config()
-    castellan.validate_config()
+    keystone.validate_config()
+    validate_castellan_config()
 
     messaging.setup(service_name)
 
     plugins_base.setup_plugins()
 
-    LOG.info(_LI('Sahara {service} started').format(service=service_name))
+    ds_manager.setup_data_sources()
+    jb_manager.setup_job_binaries()
+
+    LOG.info('Sahara {service} started'.format(service=service_name))
+
+
+def validate_castellan_config():
+    with admin_context():
+        castellan.validate_config()
 
 
 def setup_sahara_api(mode):
@@ -117,7 +130,7 @@ def _load_driver(namespace, name):
         name=name,
         invoke_on_load=True
     )
-    LOG.info(_LI("Driver {name} successfully loaded").format(name=name))
+    LOG.info("Driver {name} successfully loaded".format(name=name))
 
     return extension_manager.driver
 
@@ -149,3 +162,13 @@ def launch_api_service(launcher, service):
     launcher.launch_service(service, workers=CONF.api_workers)
     service.start()
     launcher.wait()
+
+
+@contextlib.contextmanager
+def admin_context():
+    ctx = context.get_admin_context()
+    context.set_ctx(ctx)
+    try:
+        yield
+    finally:
+        context.set_ctx(None)
